@@ -1,16 +1,20 @@
-from torch.utils.data import Dataset
-from transformers_lightning.datasets import SuperTransformersDataset
+from pytorch_lightning import Trainer
+
+from transformers_lightning.adapters.super_adapter import SuperAdapter
+from transformers_lightning.datasets.super_dataset import SuperDataset
 
 
-class TransformersMapDataset(SuperTransformersDataset, Dataset):
+class MapDataset(SuperDataset):
     r"""
     Superclass of all map datasets. Tokenization is performed on the fly.
-    Dataset is completely read into memory. If you need some lighter way of doing training, see `IterableDataset`
+    Dataset is completely read into memory.
     """
 
-    def __init__(self, *args):
-        super().__init__(*args)
-        self.data = list(iter(self.adapter))
+    def __init__(self, hparams, adapter: SuperAdapter, trainer: Trainer):
+        super().__init__(hparams)
+        self.trainer = trainer
+        self.adapter = adapter
+        self.data = list(iter(adapter))
 
     def __len__(self):
         return len(self.data)
